/***************************
 * Control rod definitions *
 ***************************/


% Control Rod Pin Upper Geometry

pin pCRUpper
B4C         0.37338
helium      0.38608
ssteel      0.48387
fill axiWater

% Control Rod Pin Lower Geometry

pin pCRLower
AgInCd      0.38227
helium      0.38608
ssteel      0.48387
fill axiWater

% Control Rod Pin Spacer Geometry

pin pCRspacer
ssteel      0.37845
helium      0.38608
ssteel      0.48387
fill axiWater

% Control Rod Pin Plenum Geometry

pin pCRplenum
inconel     0.06459
helium      0.38608
ssteel      0.48387
fill axiWater

% Stainless steel pin

pin pSsteel
ssteel      0.45720
fill axiWater


/***** Vertical layers for control rods *****/

cell cCR0 c fill axiWater                   -sCRBot
cell cCR1 c fill pSsteel    sCRBot          -sAICBot
cell cCR2 c fill pCRLower   sAICBot         -sB4CBot
cell cCR3 c fill pCRUpper   sB4CBot         -sFuelTop
cell cCR4 c fill pCRspacer  sFuelTop        -sCRplenumBot
cell cCR5 c fill pCRplenum  sCRplenumBot    -sCRplenumTop
cell cCR6 c fill pSsteel    sCRplenumTop



/***** Control rod assembly definitions *****/

% Control rod assemblies are divided to shutdown (S) and regulating (R) banks.
% 16 assemblies, named R1, R2, ..., R8, S1, S2, ..., S8.


lat R0 1 0.0 0.0 19 19  1.25984

w w w w w w w w w w w w w w w w w w w
w w w w w w w w w w w w w w w w w w w
w w w w w w w w w w w w w w w w w w w
w w w w w w w w w c w w c w w w w w w
w w w w w w w w w w w w w w c w w w w
w w w w w w w w w w w w w w w w w w w
w w w w w w w w w c w w c w w w w w w
w w w w w w w w w w w w w w w w w w w
w w w w w w w w w w w w w w w w w w w
w w w w w w w w w w w w w w w w w w w
w w w w w w w w w w w w w w w w w w w
w w w w w w w w w w w w w w w w w w w
w w w w w w w w w w w w w w w w w w w
w w w w w w w w w w w w w w w w w w w
w w w w w w w w w w w w w w w w w w w
w w w w w w w w w w w w w w w w w w w
w w w w w w w w w w w w w w w w w w w
w w w w w w w w w w w w w w w w w w w
w w w w w w w w w w w w w w w w w w w

% --- Symmetry to the lattice "R0"

set usym R0 3 2 0.0 0.0 270 45


% All control rod assemblies are identical to R0

surf sInf inf

cell cRB1 R1 fill R0 -sInf
cell cRB2 R2 fill R0 -sInf
cell cRB3 R3 fill R0 -sInf
cell cRB4 R4 fill R0 -sInf
cell cRB5 R5 fill R0 -sInf
cell cRB6 R6 fill R0 -sInf
cell cRB7 R7 fill R0 -sInf
cell cRB8 R8 fill R0 -sInf

cell cSB1 S1 fill R0 -sInf
cell cSB2 S2 fill R0 -sInf
cell cSB3 S3 fill R0 -sInf
cell cSB4 S4 fill R0 -sInf
cell cSB5 S5 fill R0 -sInf
cell cSB6 S6 fill R0 -sInf
cell cSB7 S7 fill R0 -sInf
cell cSB8 S8 fill R0 -sInf


% Regulating bank positions

lat R 1 0.0 0.0 9 9 21.50364

w  w  w  w  w  w  w  w  w
w  w  w  w  R1 w  w  w  w
w  w  w  w  w  w  w  w  w
w  w  w  w  R2 w  w  w  w
w  R3 w  R4 w  R5 w  R6 w
w  w  w  w  R7 w  w  w  w
w  w  w  w  w  w  w  w  w
w  w  w  w  R8 w  w  w  w
w  w  w  w  w  w  w  w  w

% Shutdown bank positions

lat S 1 0.0 0.0 9 9 21.50364

w  w  w  w  w  w  w  w  w
w  w  w  w  w  w  w  w  w
w  w  w  S1 w  S2 w  w  w
w  w  S3 w  w  w  S4 w  w
w  w  w  w  w  w  w  w  w
w  w  S5 w  w  w  S6 w  w
w  w  w  S7 w  S8 w  w  w
w  w  w  w  w  w  w  w  w
w  w  w  w  w  w  w  w  w


% Set the coordinates relative to the core

trans u R 1
trans u S 1


% All control rod assembly positions in core

lat CR 1 0.0 0.0 7 7 21.50364

w  w  w  R  w  w  w
w  w  S  w  S  w  w
w  S  w  R  w  S  w
R  w  R  w  R  w  R
w  S  w  R  w  S  w
w  w  S  w  S  w  w
w  w  w  R  w  w  w


% Set the coordinates relative to the core so guidetubes can be filled with control rods

trans u CR 1
